[PATCH] sim: rename TRACE_EXTRACT to CGEN_TRACE_EXTRACT

Mike Frysinger via Cgen <[email protected]> Sun, 31 Jan 2021 16:44:10 -0500
Newsgroups gmane.comp.tools.cgen.devel
Message-ID <[email protected]>
As was done for other touch points in the sim project, add a CGEN_
prefix to namespace it away from the common code.  The generated
files have already been updated years ago.

	* sim-decode.scm (TRACE_EXTRACT): Rename to ...
	(CGEN_TRACE_EXTRACT): ... this.
---
 sim-decode.scm | 10 +++++-----
 1 file changed, 5 insertions(+), 5 deletions(-)

diff --git a/sim-decode.scm b/sim-decode.scm
index aceff89da4b9..355c4853022f 100644
--- a/sim-decode.scm
+++ b/sim-decode.scm
@@ -241,7 +241,7 @@ void
 )
 
 ; gen-trace-extract method.
 ; Return appropriate arguments for TRACE_EXTRACT.
 
 (method-make!
  <hardware-base> 'gen-trace-extract
@@ -266,7 +266,7 @@ void
        ""))
 )
 
 ; Return appropriate arguments for TRACE_EXTRACT.
 
 (method-make!
  <hw-register> 'gen-trace-extract
@@ -294,7 +294,7 @@ void
 		  ";\n"))
 )
 
 ; Return appropriate arguments for TRACE_EXTRACT.
 
 (method-make!
  <hw-address> 'gen-trace-extract
@@ -320,7 +320,7 @@ void
   (send (op:type op) 'gen-extract op sfmt local?)
 )
 
 ; Return three of arguments to TRACE_EXTRACT:
 ; string argument to fprintf, character indicating type of third arg, value.
 ; The type is one of: x.
 
@@ -374,7 +374,7 @@ void
 		      iflds)
      (string-list-map (lambda (op) (/gen-op-extract op sfmt #f))
 		      operands)
-     "  TRACE_EXTRACT (current_cpu, abuf, (current_cpu, pc, "
+     "  CGEN_TRACE_EXTRACT (current_cpu, abuf, (current_cpu, pc, "
      "\"" (gen-sym sfmt) "\""
      (string-list-map (lambda (f) (/gen-trace-argbuf-ifld f sfmt))
 		      iflds)
@@ -241,7 +241,7 @@ void
 
 ; gen-trace-extract method.
-; Return appropriate arguments for TRACE_EXTRACT.
+; Return appropriate arguments for CGEN_TRACE_EXTRACT.
 
 (method-make!
@@ -266,7 +266,7 @@ void
 )
 
-; Return appropriate arguments for TRACE_EXTRACT.
+; Return appropriate arguments for CGEN_TRACE_EXTRACT.
 
 (method-make!
@@ -294,7 +294,7 @@ void
 )
 
-; Return appropriate arguments for TRACE_EXTRACT.
+; Return appropriate arguments for CGEN_TRACE_EXTRACT.
 
 (method-make!
@@ -320,7 +320,7 @@ void
 )
 
-; Return three of arguments to TRACE_EXTRACT:
+; Return three of arguments to CGEN_TRACE_EXTRACT:
 ; string argument to fprintf, character indicating type of third arg, value.
 ; The type is one of: x.
-- 
2.30.0